"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createSettingsCrud = void 0;
var _pubsub = require("@webiny/pubsub");
var _zod = _interopRequireDefault(require("zod"));
var _utils = require("@webiny/utils");
const MIN_FILE_SIZE = 0;
const MAX_FILE_SIZE = 10737418240;
const uploadMinFileSizeValidation = _zod.default.number().min(MIN_FILE_SIZE, {
  message: `Value needs to be greater than or equal to ${MIN_FILE_SIZE}.`
}).optional();
const uploadMaxFileSizeValidation = _zod.default.number().max(MAX_FILE_SIZE, {
  message: `Value needs to be lesser than or equal to ${MAX_FILE_SIZE}.`
}).optional();
const createDataModelValidation = _zod.default.object({
  uploadMinFileSize: uploadMinFileSizeValidation.default(MIN_FILE_SIZE),
  uploadMaxFileSize: uploadMaxFileSizeValidation.default(MAX_FILE_SIZE),
  srcPrefix: _zod.default.string().optional().default("/files/").transform(value => {
    if (typeof value === "string") {
      return value.endsWith("/") ? value : value + "/";
    }
    return value;
  })
});
const updateDataModelValidation = _zod.default.object({
  uploadMinFileSize: uploadMinFileSizeValidation,
  uploadMaxFileSize: uploadMaxFileSizeValidation,
  srcPrefix: _zod.default.string().optional().transform(value => {
    if (typeof value === "string") {
      return value.endsWith("/") ? value : value + "/";
    }
    return value;
  })
});
const createSettingsCrud = ({
  storageOperations,
  getTenantId
}) => {
  return {
    onSettingsBeforeUpdate: (0, _pubsub.createTopic)("fileManager.onSettingsBeforeUpdate"),
    onSettingsAfterUpdate: (0, _pubsub.createTopic)("fileManager.onSettingsAfterUpdate"),
    async getSettings() {
      return storageOperations.settings.get({
        tenant: getTenantId()
      });
    },
    async createSettings(data) {
      const results = createDataModelValidation.safeParse(data);
      if (!results.success) {
        throw (0, _utils.createZodError)(results.error);
      }
      return storageOperations.settings.create({
        data: {
          ...results.data,
          tenant: getTenantId()
        }
      });
    },
    async updateSettings(data) {
      const results = updateDataModelValidation.safeParse(data);
      if (!results.success) {
        throw (0, _utils.createZodError)(results.error);
      }
      const original = await storageOperations.settings.get({
        tenant: getTenantId()
      });
      const newSettings = {
        ...(original || {})
      };
      for (const key in results.data) {
        // @ts-expect-error
        const value = results.data[key];
        if (value === undefined) {
          continue;
        }
        // @ts-expect-error
        newSettings[key] = value;
      }
      const settings = {
        ...newSettings,
        tenant: getTenantId()
      };
      await this.onSettingsBeforeUpdate.publish({
        input: data,
        original,
        settings
      });
      const result = await storageOperations.settings.update({
        original,
        data: settings
      });
      await this.onSettingsAfterUpdate.publish({
        input: data,
        original,
        settings: result
      });
      return result;
    },
    async deleteSettings() {
      await storageOperations.settings.delete({
        tenant: getTenantId()
      });
      return true;
    }
  };
};
exports.createSettingsCrud = createSettingsCrud;

//# sourceMappingURL=settings.crud.js.map